/**
#Mechatronic Rat Head  w/ IR motion sensor input.
#
# Using a sparkfun 5V Pro Micro Arduino compatable with
# an ATmega32U4 chip that has built in USB.
#
# 
Follow directions for install here:

https://learn.sparkfun.com/tutorials/pro-micro--fio-v3-hookup-guide#installing-mac--linux

I had to download arduino 1.8.8 to get it to work on Ubuntu,
To begin, you'll need to point the Arduino IDE board manager to a 
custom URL. Open up Arduino, then go to the Preferences 
(File > Preferences). Then, towards the bottom of the window, 
paste this URL into the "Additional Board Manager URLs" text box:

https://raw.githubusercontent.com/sparkfun/Arduino_Boards/master/IDE_Board_Manager/package_sparkfun_index.json


"On Ubuntu Linux, the modem manager was grabbing the Pro Micro as soon as it was plugged in, preventing anything else, such as the Arduino IDE from being able to open the port. This is apparently a known issue, but I had to go search it down, as there is no mention of it here...

Fix:

sudo echo 'ATTRS{idVendor}=="1b4f", ENV{ID_MM_DEVICE_IGNORE}="1"' > /etc/udev/rules.d/77-arduino.rules

I found the explanation and fix on http://starter-kit.nettigo.eu/2015/serial-port-busy-for-avrdude-on-ubuntu-with-arduino-leonardo-eth/"

# Connections on Susan's project:
 Servo + (raw) note that this has a diode drop from USB +
 Servo - (gnd)
 Servo control -> Pin 3 (set to digital out)
 
 IR + (VCC) (basically USB+ on the 5.0V version of this board.
 IR - (GND)
 IR Data -> Pin 5 (set to digital in)

**/

/* Pro Micro Test Code
   by: Nathan Seidle
   modified by: Jim Lindblom
   SparkFun Electronics
   date: September 16, 2013
   license: Public Domain - please use this code however you'd like.
   It's provided as a learning tool.

   This code is provided to show how to control the SparkFun
   ProMicro's TX and RX LEDs within a sketch. It also serves
   to explain the difference between Serial.print() and
   Serial1.print().
*/


int autoActivateSeconds = 60;   // Automatically activate every XX  seconds even if no
                                // motion is detected.
int ActiveTime = 1000;   // How long to stay activated after trigger: 1,000 ms = 1 second

int PauseTime    = 5000; // How long to stay dormant after triggering: 5,000ms = 5 seconds
                         // should be a number more than 5 seconds, as the IR sensor will
                         // stay high for 3-4 seconds after a triggering event.

int servoRest = 10;       // degrees to "rest" at when not activated, should be between 10-170
int servoActive = 170;   // degrees to be at when "activated", keep between 10-170
// We only sweep the servo from 10-170 degress so that it won't hit it's end points
// and "vibrate" while not in motion.


// Pin Assignments:
int RXLED = 17;   // The RX LED has a defined Arduino pin
int SERVOPIN = 3; // Pin the SERVO control line is attached to.
int IRPIN = 5;    // Pin the IR motion sensor output line is attached to.


// note, to use with a USB power brick, must use one without a "low current auto off" 
// feature, such as this one by TalentCell:
// https://amzn.to/2HfeoBG

#include <Servo.h>
Servo myServo; 

int irMotion = 0; // data from IR motion sensor
int noMotionCount = 0; // How long in seconds it has been without motion detection


void setup()
{
 pinMode(RXLED, OUTPUT);  // Set RX LED as an output to show when active/motion detected.
 pinMode(IRPIN, INPUT); // set up the IR motion detector input.
 
 myServo.attach(SERVOPIN); // Attach servo to pin (automaticlaly sets to output)

 
 myServo.write(servoRest); // Start servo at rest degrees.
 
}

void loop()
{

 // Read from the IR motion detector.
 irMotion = digitalRead(IRPIN);   // read the IR motion input pin

 if (irMotion == HIGH || noMotionCount > autoActivateSeconds ) {

     // We detected motion, or activated due to timer, so we reset the "noMotionCount" counter to zero.
   noMotionCount = 0;
   // Move the servo to it's active setting, wait activeTime, then move back to rest.
   
      // We only sweep the servo from 10-170 degress so that it won't hit it's end points
      // and "vibrate" while not in motion.
    myServo.write(servoActive);     // Move servo to active degrees (180=max)
    digitalWrite(RXLED, LOW);   // set the RX LED ON as an indicator.
    
    delay(ActiveTime);           // wait for the "activeTime"

    myServo.write(servoRest);    // back off servo to rest degrees (0 = min)
    digitalWrite(RXLED, HIGH);    // set the RX LED OFF

    delay(PauseTime);  // IR sensor locks high for several seconds, we need to wait it out so we
                  // don't sweep the servo again for the same motion event. this also allows
                  // the system to lay dormant for a set amount of time.

 } // end IF irMotion  detected

 // If no motion was detected, we wait a second and increment no-motion count.
 delay(1000);
 noMotionCount = noMotionCount + 1;

}
